import React__default, { createElement, useState, useEffect } from 'react';
import { useDetectClickOutside } from 'react-detect-click-outside';
import { Swiper, SwiperSlide } from 'swiper/react';
import SwiperCore, { Navigation, Pagination, Scrollbar, A11y } from 'swiper';
import 'swiper/swiper.min.css';
import 'swiper/components/navigation/navigation.min.css';
import 'swiper/components/pagination/pagination.min.css';
import 'swiper/components/scrollbar/scrollbar.min.css';

var Button = function Button(_ref) {
  var label = _ref.label,
      className = _ref.className,
      icon = _ref.icon,
      action = _ref.action,
      loading = _ref.loading,
      disabled = _ref.disabled;
  var btnIcon = icon ? icon : null;
  var disabled_btn = disabled ? 'disabled' : null;
  if (loading) return React__default.createElement("button", {
    className: "btn " + className
  }, React__default.createElement("div", {
    className: 'loading-dots-animated space'
  }), " Cargando");
  return React__default.createElement("button", {
    className: "btn " + className + " " + disabled_btn,
    onClick: function onClick() {
      return action();
    }
  }, btnIcon, label);
};
var ButtonIcon = function ButtonIcon(_ref2) {
  var className = _ref2.className,
      icon = _ref2.icon,
      action = _ref2.action;
  var btnIcon = icon ? icon : null;
  return React__default.createElement("button", {
    className: "btn " + className + " btn-icon",
    onClick: function onClick() {
      return action();
    }
  }, btnIcon);
};

function validateText(text) {
  if (text && text.length > 3) {
    return true;
  }

  return false;
}

function validateEmail(email) {
  var regular_expression = /^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;

  if (email !== undefined && regular_expression.test(email)) {
    return true;
  }

  return false;
}

function validatePassword(password) {
  if (password && password.length > 3) {
    return true;
  }

  return false;
}

function validateInput(_ref) {
  var type = _ref.type,
      value = _ref.value;

  switch (type) {
    case 'text':
      return validateText(value) ? {
        status: true,
        message: ''
      } : {
        status: false,
        message: 'Debe contener al menos 3 caracteres'
      };

    case 'email':
      return validateEmail(value) ? {
        status: true,
        message: ''
      } : {
        status: false,
        message: 'Email incorrecto'
      };

    case 'password':
      return validatePassword(value) ? {
        status: true,
        message: ''
      } : {
        status: false,
        message: 'Password incorrecto'
      };

    default:
      return false;
  }
}

var Input = function Input(_ref) {
  var type = _ref.type,
      name = _ref.name,
      value = _ref.value,
      placeholder = _ref.placeholder,
      onChange = _ref.onChange,
      className = _ref.className;
  var validation = validateInput({
    type: type,
    value: value
  });
  return React__default.createElement("div", null, React__default.createElement("input", {
    type: type,
    className: "inp " + className,
    name: name,
    value: value,
    placeholder: placeholder,
    onChange: onChange
  }), validation && value && value.length > 0 ? React__default.createElement("div", {
    className: 'inp-message error'
  }, validation.message) : null);
};

var H1 = function H1(props) {
  var children = props.children,
      className = props.className;
  return React__default.createElement("h1", {
    className: className
  }, children);
};
var H2 = function H2(props) {
  var children = props.children,
      className = props.className;
  return React__default.createElement("h2", {
    className: className
  }, children);
};
var H3 = function H3(props) {
  var children = props.children,
      className = props.className;
  return React__default.createElement("h3", {
    className: className
  }, children);
};
var H4 = function H4(props) {
  var children = props.children,
      className = props.className;
  return React__default.createElement("h4", {
    className: className
  }, children);
};
var H5 = function H5(props) {
  var children = props.children,
      className = props.className;
  return React__default.createElement("h5", {
    className: className
  }, children);
};
var H6 = function H6(props) {
  var children = props.children,
      className = props.className;
  return React__default.createElement("h6", {
    className: className
  }, children);
};
var P = function P(props) {
  var children = props.children;
  return React__default.createElement("p", null, children);
};

function IconLogo(props) {
  var size = props.size ? props.size : '';
  return createElement("svg", Object.assign({
    width: "1em",
    height: "1em",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, props, {
    className: "logo " + size
  }), createElement("path", {
    d: "M26.434 6.815a2.74 2.74 0 1 0 0-5.482 2.74 2.74 0 0 0 0 5.482Z",
    fill: "#E93256"
  }), createElement("path", {
    fillRule: "evenodd",
    clipRule: "evenodd",
    d: "M29.857 13.368c-.526-1.27-2.484-1.793-5.235-1.642-2.013-2.982-5.54-4.913-9.426-4.913-6.133-.058-11.153 4.884-11.153 10.75-.004.926.114 1.849.351 2.744-1.869 1.76-2.76 3.431-2.254 4.65.556 1.329 2.656 1.842 5.604 1.632.35-.027.75-.096 1.125-.145 1.812 1.204 4 1.858 6.326 1.858 5.287 0 9.246-3.148 10.667-7.488-1.941.948-4.29 1.513-4.29 1.513.614-.331 1.74-1.072 2.487-1.579 1.188-.822 2.215-1.589 2.215-1.589v-.006a18.74 18.74 0 0 0 1.24-1.053c1.938-1.784 2.863-3.491 2.343-4.732ZM5.974 24.715c.137 0 .28-.006.418-.013 3.524-.194 5.03-1.131 5.03-1.138-3.726.329-5.615-.352-5.743-.401a9.88 9.88 0 0 1-.853-1.566c-.987.937-1.458 1.752-1.22 2.329.227.55 1.095.79 2.368.79Zm6.876-3.611a4.264 4.264 0 1 0 4.742-7.087 4.264 4.264 0 0 0-4.742 7.087ZM25.456 13.2c.44.953.73 1.968.858 3.009v.002c1.371-.888 1.55-1.806 1.371-2.243-.211-.493-1.166-.741-2.229-.768Z",
    fill: "#E93256"
  }));
}

function IconFooterLogo(props) {
  var size = props.size ? props.size : 'normal';
  return createElement("svg", Object.assign({
    width: "32",
    height: "32",
    viewBox: "0 0 62 38",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, props, {
    className: "icon " + size
  }), createElement("path", {
    d: "M56.262 23.482c1.893-.604 4.476-1.932 4.416-5.825 0-1.298-.33-2.928-1.502-4.196-2.012-2.203-5.437-2.203-7.48-2.203H29.199v4.618h21.897c.842 0 3.155-.03 3.155 2.928 0 3.29-3.124 2.958-3.695 2.958h-9.552v-3.924h-6.609V38h18.294c2.643 0 6.038 0 8.14-3.26C61.4 33.895 62 32.356 62 30.243c0-5.07-3.785-6.308-5.738-6.761zm-4.986 9.81H41.033V26.41h10.814c.991 0 3.544.03 3.544 3.26 0 3.682-3.034 3.621-4.115 3.621zM6.849 17.295L0 26.742h7.87l5.798-8.783c-1.713-.03-4.777-.181-6.82-.664z",
    fill: "#F4F4F4"
  }), createElement("path", {
    d: "M10.904 0C8.591 0 7.6.15 6.49.483 3.064 1.509 1.172 4.467 1.172 7.999c0 .694.03 2.022.72 3.53 1.022 2.295 2.824 3.26 4.987 3.804 1.232.272 4.716.634 8.05.694H22.59v10.745h6.639V0H10.904zM14.6 12.194L6.91 7.968l7.69-4.225v8.451zm7.72 0l-7.69-4.226 7.69-4.225v8.451z",
    fill: "#F4F4F4"
  }));
}

function IconInstagram(props) {
  var size = props.size ? props.size : 'normal';
  return createElement("svg", Object.assign({
    width: "32",
    height: "32",
    viewBox: "0 0 28 28",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, props, {
    className: "icon " + size
  }), createElement("g", {
    clipPath: "url(#prefix__clip0)",
    fill: "#F4F4F4"
  }, createElement("path", {
    d: "M27.973 8.232c-.066-1.488-.306-2.51-.651-3.397a6.833 6.833 0 00-1.62-2.483A6.891 6.891 0 0023.226.738c-.892-.344-1.909-.585-3.397-.65C18.33.016 17.854 0 14.052 0c-3.801 0-4.277.016-5.77.082-1.488.066-2.511.306-3.397.65A6.832 6.832 0 002.4 2.353 6.894 6.894 0 00.788 4.83C.443 5.722.203 6.739.137 8.227.066 9.725.049 10.2.049 14.003c0 3.801.017 4.277.082 5.77.066 1.488.307 2.511.651 3.397.356.941.908 1.783 1.62 2.483a6.89 6.89 0 002.477 1.614c.892.345 1.91.585 3.397.65 1.493.067 1.97.083 5.77.083 3.802 0 4.278-.016 5.771-.082 1.488-.066 2.51-.306 3.397-.651a7.162 7.162 0 004.097-4.097c.344-.891.585-1.909.65-3.397.066-1.493.083-1.969.083-5.77 0-3.802-.006-4.278-.071-5.77zM25.45 19.664c-.06 1.367-.29 2.106-.481 2.598a4.645 4.645 0 01-2.659 2.659c-.492.191-1.236.42-2.598.48-1.477.067-1.92.083-5.655.083-3.736 0-4.185-.016-5.656-.082-1.368-.06-2.106-.29-2.598-.481a4.31 4.31 0 01-1.609-1.045 4.354 4.354 0 01-1.044-1.608c-.192-.493-.421-1.236-.482-2.598-.065-1.477-.082-1.92-.082-5.656 0-3.736.017-4.185.082-5.656.06-1.368.29-2.106.482-2.598.224-.607.58-1.16 1.05-1.608.454-.465 1-.821 1.608-1.045.492-.192 1.236-.421 2.598-.481 1.477-.066 1.92-.083 5.656-.083 3.741 0 4.184.017 5.656.083 1.367.06 2.106.29 2.598.48.607.225 1.16.58 1.608 1.046.465.454.82 1 1.045 1.608.191.492.421 1.236.481 2.598.066 1.477.082 1.92.082 5.656 0 3.736-.016 4.173-.082 5.65z"
  }), createElement("path", {
    d: "M14.052 6.81a7.195 7.195 0 00-7.193 7.193 7.195 7.195 0 007.193 7.192 7.194 7.194 0 007.193-7.192 7.194 7.194 0 00-7.193-7.193zm0 11.859a4.667 4.667 0 11.002-9.334 4.667 4.667 0 01-.002 9.334zM23.208 6.526a1.68 1.68 0 11-3.359 0 1.68 1.68 0 013.36 0z"
  })), createElement("defs", null, createElement("clipPath", {
    id: "prefix__clip0"
  }, createElement("path", {
    fill: "#fff",
    d: "M0 0h28v28H0z"
  }))));
}

function IconFacebook(props) {
  var size = props.size ? props.size : 'normal';
  return createElement("svg", Object.assign({
    width: "32",
    height: "32",
    viewBox: "0 0 28 28",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, props, {
    className: "icon " + size
  }), createElement("g", {
    clipPath: "url(#prefix__clip0_16:107)"
  }, createElement("path", {
    d: "M18.663 4.65h2.556V.196C20.78.137 19.262 0 17.495 0c-3.685 0-6.21 2.318-6.21 6.579V10.5H7.218v4.977h4.067V28h4.987V15.478h3.902l.62-4.977H16.27V7.072c.002-1.438.389-2.423 2.393-2.423z",
    fill: "#F4F4F4"
  })), createElement("defs", null, createElement("clipPath", {
    id: "prefix__clip0_16:107"
  }, createElement("path", {
    fill: "#fff",
    d: "M0 0h28v28H0z"
  }))));
}

function IconYoutube(props) {
  var size = props.size ? props.size : 'normal';
  return createElement("svg", Object.assign({
    width: "32",
    height: "32",
    viewBox: "0 0 28 28",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, props, {
    className: "icon " + size
  }), createElement("path", {
    d: "M26.57 7.439a3.289 3.289 0 00-2.313-2.314c-2.054-.562-10.271-.562-10.271-.562s-8.216 0-10.27.54A3.355 3.355 0 001.401 7.44c-.54 2.054-.54 6.314-.54 6.314s0 4.28.54 6.313a3.29 3.29 0 002.314 2.314c2.075.562 10.27.562 10.27.562s8.217 0 10.27-.54a3.289 3.289 0 002.315-2.314c.54-2.054.54-6.314.54-6.314s.022-4.281-.54-6.335zm-15.2 10.249v-7.87l6.833 3.935-6.833 3.935z",
    fill: "#F4F4F4"
  }));
}

function IconTikTok(props) {
  var size = props.size ? props.size : 'normal';
  return createElement("svg", Object.assign({
    width: "32",
    height: "32",
    viewBox: "0 0 28 28",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, props, {
    className: "icon " + size
  }), createElement("path", {
    d: "M26.267 7.021A7.044 7.044 0 0122.011 5.6 7.06 7.06 0 0119.197.02h-4.564v12.473l-.006 6.832a4.132 4.132 0 01-2.838 3.92 4.153 4.153 0 01-1.534.204 4.114 4.114 0 01-1.89-.58 4.131 4.131 0 01-2.02-3.481 4.135 4.135 0 014.141-4.192c.456 0 .893.074 1.303.209V10.77a8.98 8.98 0 00-1.316-.097 8.753 8.753 0 00-6.578 2.942 8.563 8.563 0 00-2.16 5.165 8.552 8.552 0 002.547 6.663 8.754 8.754 0 006.19 2.534 8.98 8.98 0 001.317-.097 8.724 8.724 0 004.874-2.437 8.546 8.546 0 002.563-6.082L19.203 9.16a11.54 11.54 0 007.078 2.405V7.02l-.014.001z",
    fill: "#F4F4F4"
  }));
}

function IconPlayCircle(props) {
  var size = props.size ? props.size : 'normal';
  return createElement("svg", Object.assign({
    width: "1em",
    height: "1em",
    viewBox: "0 0 32 32",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, props, {
    className: "icon " + size
  }), createElement("path", {
    d: "M31.992 15.479C31.724 7.072 24.928.277 16.522.008 11.948-.136 7.67 1.605 4.507 4.87 1.467 8.009-.131 12.147.008 16.523c.269 8.406 7.064 15.2 15.47 15.47a15.872 15.872 0 0012.016-4.861c3.04-3.14 4.638-7.278 4.498-11.653zm-6.919 9.308a12.53 12.53 0 01-9.488 3.838c-6.634-.212-11.997-5.575-12.209-12.21a12.54 12.54 0 013.55-9.2 12.53 12.53 0 019.489-3.838c6.634.212 11.997 5.574 12.21 12.209a12.541 12.541 0 01-3.552 9.2z",
    fill: "#fff"
  }), createElement("path", {
    d: "M21.248 15.07l-7.095-5.087a1.144 1.144 0 00-1.81.93v10.175a1.144 1.144 0 001.81.93l7.095-5.088a1.144 1.144 0 000-1.86z",
    fill: "#fff"
  }));
}

function IconInfo(props) {
  var size = props.size ? props.size : 'normal';
  return createElement("svg", Object.assign({
    width: "1em",
    height: "1em",
    viewBox: "0 0 32 32",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, props, {
    className: "icon " + size
  }), createElement("path", {
    d: "M31.992 15.478C31.724 7.072 24.928.277 16.522.008 11.948-.137 7.67 1.604 4.507 4.87 1.467 8.008-.131 12.147.008 16.522c.269 8.406 7.064 15.202 15.47 15.47a15.872 15.872 0 0012.016-4.861c3.04-3.14 4.638-7.278 4.498-11.653zm-6.919 9.308a12.529 12.529 0 01-9.488 3.838c-6.634-.212-11.997-5.575-12.209-12.209a12.54 12.54 0 013.55-9.201 12.53 12.53 0 019.489-3.838c6.634.212 11.997 5.575 12.21 12.21a12.541 12.541 0 01-3.552 9.2z",
    fill: "#fff"
  }), createElement("path", {
    d: "M16.06 14a2 2 0 012 2v6a2 2 0 01-4 0v-6a2 2 0 012-2zM15.882 8.001a2 2 0 100 4 2 2 0 000-4z",
    fill: "#fff"
  }));
}

function IconFilter(props) {
  var size = props.size ? props.size : 'normal';
  return createElement("svg", Object.assign({
    width: "1em",
    height: "1em",
    viewBox: "0 0 28 28",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, props, {
    className: "icon " + size
  }), createElement("path", {
    d: "M4.958 6.545c2.357 3.022 6.709 8.622 6.709 8.622v7a1.17 1.17 0 001.166 1.166h2.334a1.17 1.17 0 001.166-1.166v-7s4.34-5.6 6.697-8.622a1.164 1.164 0 00-.922-1.878H5.88a1.164 1.164 0 00-.922 1.878z",
    fill: "#FFFFFF"
  }));
}

function IconUser(props) {
  var size = props.size ? props.size : 'normal';
  return createElement("svg", Object.assign({
    width: "1em",
    height: "1em",
    viewBox: "0 0 28 28",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, props, {
    className: "icon " + size
  }), createElement("path", {
    d: "M14 2.333C7.56 2.333 2.333 7.56 2.333 14c0 6.44 5.227 11.667 11.667 11.667 6.44 0 11.667-5.227 11.667-11.667C25.667 7.56 20.44 2.333 14 2.333zm0 3.5c1.937 0 3.5 1.564 3.5 3.5 0 1.937-1.563 3.5-3.5 3.5a3.495 3.495 0 01-3.5-3.5c0-1.936 1.563-3.5 3.5-3.5zM14 22.4a8.4 8.4 0 01-7-3.757c.035-2.321 4.667-3.593 7-3.593 2.322 0 6.965 1.272 7 3.593a8.4 8.4 0 01-7 3.757z",
    fill: "#4F00BA"
  }));
}

function IconClose(props) {
  var size = props.size ? props.size : 'normal';
  return createElement("svg", Object.assign({
    width: "1em",
    height: "1em",
    viewBox: "0 0 32 32",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, props, {
    className: "icon " + size
  }), createElement("path", {
    d: "M14.09 19.59 15.5 21l5-5-5-5-1.41 1.41L16.67 15H7v2h9.67l-2.58 2.59ZM23 7H9a2 2 0 0 0-2 2v4h2V9h14v14H9v-4H7v4a2 2 0 0 0 2 2h14c1.1 0 2-.9 2-2V9c0-1.1-.9-2-2-2Z",
    fill: "#fff"
  }));
}

function IconClose$1(props) {
  var size = props.size ? props.size : 'normal';
  return createElement("svg", Object.assign({
    width: "1em",
    height: "1em",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, props, {
    className: "icon " + size
  }), createElement("circle", {
    cx: 14,
    cy: 14,
    r: 10,
    fill: "#fff"
  }), createElement("path", {
    d: "M18.769 16.526 16.244 14l2.524-2.525a.796.796 0 0 0 0-1.122L17.645 9.23a.797.797 0 0 0-1.122 0l-2.525 2.525-2.524-2.525a.797.797 0 0 0-1.122 0l-1.12 1.122a.796.796 0 0 0 0 1.122L11.755 14 9.23 16.526a.796.796 0 0 0 0 1.121l1.122 1.122a.795.795 0 0 0 1.122 0l2.524-2.524 2.524 2.523a.797.797 0 0 0 1.124 0l1.122-1.12a.796.796 0 0 0 0-1.122Z",
    fill: "#000"
  }));
}

function IconMenu(props) {
  var size = props.size ? props.size : 'normal';
  return createElement("svg", Object.assign({
    width: "1em",
    height: "1em",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, props, {
    className: "icon " + size
  }), createElement("path", {
    d: "M24.25 15.25H7.75a.75.75 0 0 0 0 1.5h16.5a.75.75 0 0 0 0-1.5ZM24.25 10H7.75a.75.75 0 0 0 0 1.5h16.5a.75.75 0 0 0 0-1.5ZM24.25 20.5H7.75a.75.75 0 0 0 0 1.5h16.5a.75.75 0 0 0 0-1.5Z",
    fill: "#858B94"
  }));
}

function IconApps(props) {
  var size = props.size ? props.size : 'normal';
  return createElement("svg", Object.assign({
    width: "1em",
    height: "1em",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, props, {
    className: "icon " + size
  }), createElement("path", {
    d: "M12.25 7.333H10a3 3 0 0 0-3 3v2.25a3 3 0 0 0 3 3h2.25a3 3 0 0 0 3-3v-2.25a3 3 0 0 0-3-3ZM22 7.333h-2.25a3 3 0 0 0-3 3v2.25a3 3 0 0 0 3 3H22a3 3 0 0 0 3-3v-2.25a3 3 0 0 0-3-3ZM12.25 17.083H10a3 3 0 0 0-3 3v2.25a3 3 0 0 0 3 3h2.25a3 3 0 0 0 3-3v-2.25a3 3 0 0 0-3-3ZM22 17.083h-2.25a3 3 0 0 0-3 3v2.25a3 3 0 0 0 3 3H22a3 3 0 0 0 3-3v-2.25a3 3 0 0 0-3-3Z",
    fill: "#101B29"
  }));
}

function IconGraduation(props) {
  var size = props.size ? props.size : 'normal';
  return createElement("svg", Object.assign({
    width: "1em",
    height: "1em",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, props, {
    className: "icon " + size
  }), createElement("path", {
    d: "M24.906 12.657a2.91 2.91 0 0 0-1.363-1.735l-5.53-2.634a3.92 3.92 0 0 0-3.963-.034l-5.593 2.668-.063.034a2.768 2.768 0 0 0 .063 4.841l1.543.735v3.675a3.755 3.755 0 0 0 2.64 3.584c1.091.316 2.223.47 3.36.459a11.67 11.67 0 0 0 3.36-.455A3.755 3.755 0 0 0 22 20.21v-3.68l1.5-.717V22a.75.75 0 1 0 1.5 0v-9a.728.728 0 0 0-.094-.343ZM20.5 20.211a2.25 2.25 0 0 1-1.575 2.148c-.95.271-1.936.403-2.925.391-.989.012-1.974-.12-2.925-.392a2.25 2.25 0 0 1-1.575-2.147v-2.964l2.488 1.185a3.954 3.954 0 0 0 2.029.555 3.75 3.75 0 0 0 1.932-.521l2.551-1.219v2.964Zm2.4-5.767-5.656 2.7a2.472 2.472 0 0 1-2.543-.034l-5.534-2.633a1.268 1.268 0 0 1-.028-2.218l5.621-2.685a2.475 2.475 0 0 1 2.543.034l5.53 2.634a1.295 1.295 0 0 1 .667 1.118 1.275 1.275 0 0 1-.6 1.084Z",
    fill: "#A3ABB5"
  }));
}

function IconDiploma(props) {
  var size = props.size ? props.size : 'normal';
  return createElement("svg", Object.assign({
    width: "1em",
    height: "1em",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, props, {
    className: "icon " + size
  }), createElement("path", {
    d: "M15.25 16a.75.75 0 1 1 0 1.5H13a.75.75 0 1 1 0-1.5h2.25Zm4.5-2.25A.75.75 0 0 0 19 13h-6a.75.75 0 1 0 0 1.5h6a.75.75 0 0 0 .75-.75ZM13 11.5h6a.75.75 0 1 0 0-1.5h-6a.75.75 0 1 0 0 1.5Zm9 10.083v2.875a.54.54 0 0 1-.923.382l-.577-.576-.577.576a.542.542 0 0 1-.923-.382v-2.875A2.99 2.99 0 0 1 20.5 16c.253.003.506.039.75.107V10.75A2.25 2.25 0 0 0 19 8.5h-6a2.25 2.25 0 0 0-2.25 2.25v9A2.25 2.25 0 0 0 13 22h3.75a.75.75 0 1 1 0 1.5H13a3.754 3.754 0 0 1-3.75-3.75v-9A3.754 3.754 0 0 1 13 7h6a3.754 3.754 0 0 1 3.75 3.75v6.287a2.962 2.962 0 0 1-.75 4.546ZM22 19a1.5 1.5 0 1 0-3 0 1.5 1.5 0 0 0 3 0Z",
    fill: "#A3ABB5"
  }));
}

function IconStats(props) {
  var size = props.size ? props.size : 'normal';
  return createElement("svg", Object.assign({
    width: "1em",
    height: "1em",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, props, {
    className: "icon " + size
  }), createElement("g", {
    clipPath: "url(#a)",
    fill: "#A3ABB5"
  }, createElement("path", {
    d: "M24.25 23.5h-15a.75.75 0 0 1-.75-.75v-15a.75.75 0 0 0-1.5 0v15A2.25 2.25 0 0 0 9.25 25h15a.75.75 0 1 0 0-1.5Z"
  }), createElement("path", {
    d: "M18.25 22a.75.75 0 0 0 .75-.75V16a.75.75 0 1 0-1.5 0v5.25a.75.75 0 0 0 .75.75ZM12.25 22a.75.75 0 0 0 .75-.75V16a.75.75 0 1 0-1.5 0v5.25a.75.75 0 0 0 .75.75ZM21.25 22a.75.75 0 0 0 .75-.75v-9a.75.75 0 1 0-1.5 0v9a.75.75 0 0 0 .75.75ZM15.25 22a.75.75 0 0 0 .75-.75v-9a.75.75 0 1 0-1.5 0v9a.75.75 0 0 0 .75.75Z"
  })), createElement("defs", null, createElement("clipPath", {
    id: "a"
  }, createElement("path", {
    fill: "#fff",
    transform: "translate(7 7)",
    d: "M0 0h18v18H0z"
  }))));
}

function IconMoney(props) {
  var size = props.size ? props.size : 'normal';
  return createElement("svg", Object.assign({
    width: "1em",
    height: "1em",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, props, {
    className: "icon " + size
  }), createElement("path", {
    d: "M21.25 22h-10.5A3.755 3.755 0 0 1 7 18.25v-4.5A3.754 3.754 0 0 1 10.75 10h10.5A3.754 3.754 0 0 1 25 13.75v4.5A3.754 3.754 0 0 1 21.25 22Zm-10.5-10.5a2.25 2.25 0 0 0-2.25 2.25v4.5a2.25 2.25 0 0 0 2.25 2.25h10.5a2.25 2.25 0 0 0 2.25-2.25v-4.5a2.25 2.25 0 0 0-2.25-2.25h-10.5ZM16 19a3 3 0 1 1 0-5.999A3 3 0 0 1 16 19Zm0-4.5a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3ZM10.75 13a.75.75 0 1 0 0 1.5.75.75 0 0 0 0-1.5Zm9.75.75a.75.75 0 1 0 1.5 0 .75.75 0 0 0-1.5 0Zm-9.75 3.75a.75.75 0 1 0 0 1.5.75.75 0 0 0 0-1.5Zm9.75.75a.75.75 0 1 0 1.5 0 .75.75 0 0 0-1.5 0Z",
    fill: "#A3ABB5"
  }));
}

function IconHelp(props) {
  var size = props.size ? props.size : 'normal';
  return createElement("svg", Object.assign({
    width: "1em",
    height: "1em",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, props, {
    className: "icon " + size
  }), createElement("g", {
    clipPath: "url(#a)",
    fill: "#A3ABB5"
  }, createElement("path", {
    d: "M16 7a9 9 0 1 0 9 9 9.01 9.01 0 0 0-9-9Zm0 16.5a7.5 7.5 0 1 1 7.5-7.5 7.509 7.509 0 0 1-7.5 7.5Z"
  }), createElement("path", {
    d: "M16.538 10.797A2.999 2.999 0 0 0 13 13.75a.75.75 0 1 0 1.5 0 1.5 1.5 0 0 1 2.56-1.06c.214.213.36.485.418.781a1.5 1.5 0 0 1-.75 1.594 2.964 2.964 0 0 0-1.478 2.628v.557a.75.75 0 1 0 1.5 0v-.557a1.486 1.486 0 0 1 .698-1.314 3 3 0 0 0-.91-5.582ZM16.75 20.5a.75.75 0 1 0-1.5 0 .75.75 0 0 0 1.5 0Z"
  })), createElement("defs", null, createElement("clipPath", {
    id: "a"
  }, createElement("path", {
    fill: "#fff",
    transform: "translate(7 7)",
    d: "M0 0h18v18H0z"
  }))));
}

function IconDots(props) {
  var size = props.size ? props.size : 'normal';
  return createElement("svg", Object.assign({
    width: "1em",
    height: "1em",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, props, {
    className: "icon " + size
  }), createElement("path", {
    d: "M6 18a2 2 0 1 0 0-4 2 2 0 0 0 0 4ZM16 18a2 2 0 1 0 0-4 2 2 0 0 0 0 4ZM26 18a2 2 0 1 0 0-4 2 2 0 0 0 0 4Z",
    fill: "#000"
  }));
}

function IconTicket(props) {
  var size = props.size ? props.size : 'normal';
  return createElement("svg", Object.assign({
    width: "1em",
    height: "1em",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, props, {
    className: "icon " + size
  }), createElement("path", {
    d: "M8 32.5h2.84a2.694 2.694 0 0 0 2.588-2.043 2.667 2.667 0 0 1 5.144 0A2.693 2.693 0 0 0 21.16 32.5H24a4 4 0 0 0 4-4v-5.333h-5.333a1.333 1.333 0 1 1 0-2.667H28V7.167A6.675 6.675 0 0 0 21.333.5h-.173a2.693 2.693 0 0 0-2.588 2.043 2.667 2.667 0 0 1-5.144 0A2.693 2.693 0 0 0 10.84.5h-.173A6.675 6.675 0 0 0 4 7.167V20.5h5.333a1.333 1.333 0 0 1 0 2.667H4V28.5a4 4 0 0 0 4 4Zm6.667-12h2.666a1.333 1.333 0 1 1 0 2.667h-2.666a1.333 1.333 0 1 1 0-2.667Z",
    fill: '#7FBA7A'
  }));
}

var IconLogo$1 = function IconLogo$1(_ref) {
  var size = _ref.size;
  return React__default.createElement(IconLogo, {
    size: size
  });
};

var IconFooterLogo$1 = function IconFooterLogo$1(_ref2) {
  var size = _ref2.size;
  return React__default.createElement(IconFooterLogo, {
    size: size
  });
};

var IconInstagram$1 = function IconInstagram$1(_ref3) {
  var size = _ref3.size;
  return React__default.createElement(IconInstagram, {
    size: size
  });
};

var IconFacebook$1 = function IconFacebook$1(_ref4) {
  var size = _ref4.size;
  return React__default.createElement(IconFacebook, {
    size: size
  });
};

var IconYoutube$1 = function IconYoutube$1(_ref5) {
  var size = _ref5.size;
  return React__default.createElement(IconYoutube, {
    size: size
  });
};

var IconTikTok$1 = function IconTikTok$1(_ref6) {
  var size = _ref6.size;
  return React__default.createElement(IconTikTok, {
    size: size
  });
};

var IconPlayCircle$1 = function IconPlayCircle$1(_ref7) {
  var size = _ref7.size;
  return React__default.createElement(IconPlayCircle, {
    size: size
  });
};

var IconInfo$1 = function IconInfo$1(_ref8) {
  var size = _ref8.size;
  return React__default.createElement(IconInfo, {
    size: size
  });
};

var IconClose$2 = function IconClose(_ref9) {
  var size = _ref9.size;
  return React__default.createElement(IconClose$1, {
    size: size
  });
};

var IconFilter$1 = function IconFilter$1(_ref10) {
  var size = _ref10.size;
  return React__default.createElement(IconFilter, {
    size: size
  });
};

var IconUser$1 = function IconUser$1(_ref11) {
  var size = _ref11.size;
  return React__default.createElement(IconUser, {
    size: size
  });
};

var IconExit = function IconExit(_ref12) {
  var size = _ref12.size;
  return React__default.createElement(IconClose, {
    size: size
  });
};

var IconMenu$1 = function IconMenu$1(_ref13) {
  var size = _ref13.size;
  return React__default.createElement(IconMenu, {
    size: size
  });
};

var IconApps$1 = function IconApps$1(_ref14) {
  var size = _ref14.size;
  return React__default.createElement(IconApps, {
    size: size
  });
};

var IconGraduation$1 = function IconGraduation$1(_ref15) {
  var size = _ref15.size;
  return React__default.createElement(IconGraduation, {
    size: size
  });
};

var IconDiploma$1 = function IconDiploma$1(_ref16) {
  var size = _ref16.size;
  return React__default.createElement(IconDiploma, {
    size: size
  });
};

var IconStats$1 = function IconStats$1(_ref17) {
  var size = _ref17.size;
  return React__default.createElement(IconStats, {
    size: size
  });
};

var IconMoney$1 = function IconMoney$1(_ref18) {
  var size = _ref18.size;
  return React__default.createElement(IconMoney, {
    size: size
  });
};

var IconHelp$1 = function IconHelp$1(_ref19) {
  var size = _ref19.size;
  return React__default.createElement(IconHelp, {
    size: size
  });
};

var IconDots$1 = function IconDots$1(_ref20) {
  var size = _ref20.size;
  return React__default.createElement(IconDots, {
    size: size
  });
};

var IconTicket$1 = function IconTicket$1(_ref21) {
  var size = _ref21.size;
  return React__default.createElement(IconTicket, {
    size: size
  });
};

var Icons = {
  __proto__: null,
  IconLogo: IconLogo$1,
  IconFooterLogo: IconFooterLogo$1,
  IconInstagram: IconInstagram$1,
  IconFacebook: IconFacebook$1,
  IconYoutube: IconYoutube$1,
  IconTikTok: IconTikTok$1,
  IconPlayCircle: IconPlayCircle$1,
  IconInfo: IconInfo$1,
  IconClose: IconClose$2,
  IconFilter: IconFilter$1,
  IconUser: IconUser$1,
  IconExit: IconExit,
  IconMenu: IconMenu$1,
  IconApps: IconApps$1,
  IconGraduation: IconGraduation$1,
  IconDiploma: IconDiploma$1,
  IconStats: IconStats$1,
  IconMoney: IconMoney$1,
  IconHelp: IconHelp$1,
  IconDots: IconDots$1,
  IconTicket: IconTicket$1
};

function setCookie(_ref) {
  var cname = _ref.cname,
      cvalue = _ref.cvalue,
      exdays = _ref.exdays;
  var d = new Date();
  d.setTime(d.getTime() + exdays * 24 * 60 * 60 * 1000);
  var expires = "expires=" + d.toUTCString();
  document.cookie = cname + "=" + cvalue + ";" + expires + ";path=/";
}
function getCookie(_ref2) {
  var cname = _ref2.cname;
  var name = cname + "=";
  var ca = document.cookie.split(';');

  for (var i = 0; i < ca.length; i++) {
    var c = ca[i];

    while (c.charAt(0) == ' ') {
      c = c.substring(1);
    }

    if (c.indexOf(name) == 0) {
      return c.substring(name.length, c.length);
    }
  }

  return "";
}
function getSession() {
  var session_token = getCookie({
    cname: 'session_token'
  }) ? getCookie({
    cname: 'session_token'
  }) : '';
  var session_token_decoded = session_token.substring(3, session_token.length);
  var session_token_json = getCookie({
    cname: 'session_token'
  }) ? JSON.parse(decodeString(session_token_decoded)) : {
    account: {
      id: null
    }
  };
  var account = session_token_json.account;
  var tokens = {
    api_payment: '',
    api_account: ''
  };
  var payments = {
    status: 'active'
  };
  var data = {
    account: account,
    tokens: tokens,
    payments: payments
  };
  return data;
}
function setSession(_ref3) {
  var user = _ref3.user;
  var account = user ? user : {
    id: null
  };
  var tokens = {
    api_payment: '',
    api_account: ''
  };
  var payments = {
    status: 'active'
  };
  var data = {
    application: 'rebaila',
    account: account,
    tokens: tokens,
    payments: payments
  };
  return encodeString(JSON.stringify(data));
}
function encodeString(string) {
  var encodedString = btoa(string);
  return encodedString;
}
function decodeString(encodedString) {
  var decodedString = atob(encodedString);
  return decodedString;
}

function slugify(str) {
  str = str.replace(/^\s+|\s+$/g, '');
  str = str.toLowerCase();
  var from = "ÁÄÂÀÃÅČÇĆĎÉĚËÈÊẼĔȆÍÌÎÏŇÑÓÖÒÔÕØŘŔŠŤÚŮÜÙÛÝŸŽáäâàãåčçćďéěëèêẽĕȇíìîïňñóöòôõøðřŕšťúůüùûýÿžþÞĐđßÆa·/_,:;";
  var to = "AAAAAACCCDEEEEEEEEIIIINNOOOOOORRSTUUUUUYYZaaaaaacccdeeeeeeeeiiiinnooooooorrstuuuuuyyzbBDdBAa------";

  for (var i = 0, l = from.length; i < l; i++) {
    str = str.replace(new RegExp(from.charAt(i), 'g'), to.charAt(i));
  }

  str = str.replace(/[^a-z0-9 -]/g, '').replace(/\s+/g, '-').replace(/-+/g, '-');
  return str;
}
function amountPriceDecimal(price) {
  var amountCent = String(price);
  var convertCentToPrice = amountCent.substring(0, amountCent.length - 2);
  var convertCentToPriceDecimal = amountCent.substring(amountCent.length - 2, amountCent.length);
  var price_format = convertCentToPrice + '.' + convertCentToPriceDecimal;
  return Number.parseFloat(price_format).toFixed(2);
}

var getWindowDimensions = function getWindowDimensions() {
  var _window = window,
      width = _window.innerWidth;
  var device = 'desktop';

  if (width < 768) {
    device = 'mobile';
  } else {
    device = 'desktop';
  }

  return {
    device: device
  };
};

function useWindowDimensions() {
  var _useState = useState(getWindowDimensions()),
      windowDimensions = _useState[0],
      setWindowDimensions = _useState[1];

  useEffect(function () {
    function handleResize() {
      setWindowDimensions(getWindowDimensions());
    }

    window.addEventListener('resize', handleResize);
    return function () {
      return window.removeEventListener('resize', handleResize);
    };
  }, []);
  return windowDimensions;
}

function showAlert() {
  alert('test');
}

var appendScript = function appendScript(scriptToAppend) {
  var script = document.createElement("script");
  script.src = scriptToAppend;
  script.async = true;
  document.body.appendChild(script);
};

var JS = {
  __proto__: null,
  showAlert: showAlert,
  setCookie: setCookie,
  getCookie: getCookie,
  decodeString: decodeString,
  encodeString: encodeString,
  appendScript: appendScript,
  setSession: setSession,
  getSession: getSession,
  slugify: slugify,
  amountPriceDecimal: amountPriceDecimal,
  useWindowDimensions: useWindowDimensions
};

var Dropdown = function Dropdown(_ref) {
  var closeToggle = _ref.closeToggle,
      children = _ref.children;
  var ref = useDetectClickOutside({
    onTriggered: closeToggle
  });
  return React__default.createElement("div", {
    className: "dropdown",
    ref: ref
  }, children);
};

var Header = function Header(_ref2) {
  var children = _ref2.children;

  var _JS$useWindowDimensio = useWindowDimensions(),
      device = _JS$useWindowDimensio.device;

  var session = getSession();
  var style = {
    display: "flex"
  };

  var _useState = useState(false),
      toggleDropdown = _useState[0],
      setToggleDropdown = _useState[1];

  var handleToggle = function handleToggle(e) {
    e.preventDefault();
    setToggleDropdown(function (prevState) {
      return !prevState;
    });
  };

  var closeToggle = function closeToggle() {
    setToggleDropdown(false);
  };

  console.log('device: ', device);

  if (device === 'mobile') {
    return React__default.createElement("header", {
      className: 'header-mobile',
      style: style
    }, React__default.createElement("div", {
      className: "wrapper-content"
    }, React__default.createElement("div", null, React__default.createElement("a", {
      href: session.account.id !== null ? 'https://' : './'
    }, React__default.createElement(IconLogo$1, null)))), React__default.createElement("div", {
      className: "wrapper-session"
    }, React__default.createElement("button", {
      className: "btn-transparent btn-user",
      onClick: handleToggle
    }, React__default.createElement(IconMenu$1, null))), React__default.createElement("div", {
      className: "mobile-menu  "
    }, toggleDropdown && React__default.createElement(Dropdown, {
      closeToggle: closeToggle
    }, session.account.id !== null ? React__default.createElement("div", {
      className: "wrapper-nav "
    }, children, React__default.createElement("ul", null, React__default.createElement("li", null, React__default.createElement("a", {
      href: "/profile"
    }, "Mi cuenta")), React__default.createElement("li", null, React__default.createElement("a", {
      href: "/close"
    }, "Salir")))) : React__default.createElement("div", {
      className: "wrapper-nav"
    }, children, React__default.createElement("ul", {
      className: 'align-btn-session'
    }, React__default.createElement("li", null, React__default.createElement("a", {
      href: "/login",
      className: "btn-session"
    }, "Inicia sesi\xF3n")), React__default.createElement("li", null, React__default.createElement("a", {
      href: "/signUp",
      className: "btn-session btn-sign-up"
    }, "Reg\xEDstrate")))))));
  } else {
    return React__default.createElement("header", {
      className: 'header-desktop',
      style: style
    }, React__default.createElement("div", {
      className: "wrapper-content"
    }, React__default.createElement("div", null, React__default.createElement("a", {
      href: session.account.id !== null ? '/dashboard' : './'
    }, React__default.createElement(IconLogo$1, null)))), session.account.id !== null ? React__default.createElement("div", {
      className: "wrapper-session"
    }, React__default.createElement("div", {
      className: "wrapper-nav"
    }, children), React__default.createElement("div", {
      className: "item"
    }, React__default.createElement("button", {
      className: "btn-transparent btn-user",
      onClick: handleToggle
    }, React__default.createElement("div", {
      className: "label"
    }, session.account.firstname), " ", React__default.createElement(IconUser$1, null))), toggleDropdown && React__default.createElement(Dropdown, {
      closeToggle: closeToggle
    }, React__default.createElement("div", {
      className: "header-menu-session hidden"
    }, React__default.createElement("div", {
      className: "item"
    }, React__default.createElement("a", {
      href: "https://account.rebaila.com/profile"
    }, "Mi cuenta")), React__default.createElement("div", {
      className: "item"
    }, React__default.createElement("a", {
      href: "https://account.rebaila.com/close"
    }, "Salir"))))) : React__default.createElement("div", {
      className: "wrapper-session no-margin-right"
    }, React__default.createElement("a", {
      href: "https://account.rebaila.com",
      className: "btn-session"
    }, "Inicia sesi\xF3n"), React__default.createElement("a", {
      href: "https://account.rebaila.com/signUp",
      className: "btn-session btn-sign-up"
    }, "Reg\xEDstrate")));
  }
};

var Container = function Container(_ref) {
  var children = _ref.children,
      className = _ref.className;
  var styleClassName = className ? className : '';
  return React__default.createElement("div", {
    className: "container " + styleClassName
  }, children);
};
var Section = function Section(_ref2) {
  var children = _ref2.children,
      maxWidth = _ref2.maxWidth,
      className = _ref2.className,
      bgImage = _ref2.bgImage;
  var styleClassName = className ? className : '';

  var maximunWidth = function maximunWidth(maxWidth) {
    switch (maxWidth) {
      case 'small':
        return '580px';

      case 'medium':
        return '900px';

      case 'large':
        return '1200px';

      default:
        return '100%';
    }
  };

  var styleUpdate = {
    content: {
      maxWidth: maximunWidth(maxWidth)
    },
    bgImage: {
      backgroundImage: "url(\"" + bgImage + "\")"
    }
  };
  return React__default.createElement("div", {
    className: "section " + styleClassName,
    style: bgImage ? styleUpdate.bgImage : undefined
  }, React__default.createElement("div", {
    style: styleUpdate.content,
    className: 'sectionContent'
  }, children));
};
var Row = function Row(_ref3) {
  var children = _ref3.children,
      className = _ref3.className;
  var styleClassName = className ? className : '';
  return React__default.createElement("div", {
    className: "row " + styleClassName
  }, children);
};
var Col = function Col(_ref4) {
  var children = _ref4.children,
      className = _ref4.className;
  var styleClassName = className ? className : '';
  return React__default.createElement("div", {
    className: "col " + styleClassName
  }, children);
};
var LineDivisor = function LineDivisor(_ref5) {
  var className = _ref5.className;
  var styleClassName = className ? className : '';
  return React__default.createElement("div", {
    className: "line-divisor " + styleClassName
  });
};

var Table = function Table(_ref) {
  var children = _ref.children,
      className = _ref.className;
  var styleClassName = className ? className : '';
  return React__default.createElement("table", {
    className: "tables " + styleClassName
  }, children);
};
var Thead = function Thead(_ref2) {
  var children = _ref2.children;
  return React__default.createElement("thead", null, children);
};
var Tbody = function Tbody(_ref3) {
  var children = _ref3.children;
  return React__default.createElement("tbody", null, children);
};
var Th = function Th(_ref4) {
  var children = _ref4.children,
      className = _ref4.className;
  var styleClassName = className ? className : '';
  return React__default.createElement("th", {
    className: "th " + styleClassName
  }, children);
};
var Tr = function Tr(_ref5) {
  var children = _ref5.children,
      className = _ref5.className;
  var styleClassName = className ? className : '';
  return React__default.createElement("tr", {
    className: "tr " + styleClassName
  }, children);
};
var Td = function Td(_ref6) {
  var children = _ref6.children,
      className = _ref6.className;
  var styleClassName = className ? className : '';
  return React__default.createElement("td", {
    className: "td " + styleClassName
  }, children);
};

var Footer = function Footer(_ref) {
  var children = _ref.children;
  var year = new Date().getFullYear();
  return React__default.createElement("footer", {
    className: 'footer'
  }, React__default.createElement("div", {
    className: 'wrapper-left'
  }, React__default.createElement("div", {
    className: 'logo-footer'
  }, React__default.createElement(IconFooterLogo$1, {
    size: 'large'
  })), React__default.createElement("div", null, React__default.createElement("div", null, "\xA9 ", year, " Rebaila. All Rights Reserved."), React__default.createElement("div", null, React__default.createElement("a", {
    href: "https://rebaila.com/politica-cookies.pdf",
    target: "_blank"
  }, "Pol\xEDtica de privacidad"), " | ", React__default.createElement("a", {
    href: "https://rebaila.com/terminos-condiciones-rebaila.pdf",
    target: "_blank"
  }, "T\xE9rminos y condiciones")))), React__default.createElement("div", null, children), React__default.createElement("div", {
    className: 'wrapper-right'
  }, React__default.createElement("div", {
    className: "social-nav-wrapper"
  }, React__default.createElement("div", {
    className: "item"
  }, React__default.createElement("a", {
    href: "https://www.instagram.com/rebailastudio/",
    target: "_blank"
  }, React__default.createElement(IconInstagram$1, null))), React__default.createElement("div", {
    className: "item"
  }, React__default.createElement("a", {
    href: "https://www.facebook.com/rebailastudio/",
    target: "_blank"
  }, React__default.createElement(IconFacebook$1, null))), React__default.createElement("div", {
    className: "item"
  }, React__default.createElement("a", {
    href: "https://www.youtube.com/channel/UCU4dynpkXbAK131K89Y7Ykg",
    target: "_blank"
  }, React__default.createElement(IconYoutube$1, null))), React__default.createElement("div", {
    className: "item"
  }, React__default.createElement("a", {
    href: "https://vm.tiktok.com/ZSvHxFLP/",
    target: "_blank"
  }, React__default.createElement(IconTikTok$1, null))))));
};

var Notification = function Notification(_ref) {
  var children = _ref.children,
      className = _ref.className;
  return React__default.createElement("div", {
    className: "notification " + className
  }, children);
};

var Player = function Player(_ref) {
  var videoID = _ref.videoID,
      className = _ref.className;
  var host = 'http://localhost:4242';
  var url_player = "<iframe src='" + host + "' id='video' videoID='" + videoID + "' allow=\"camera;microphone \" />";
  return React__default.createElement("div", {
    className: "player-wrapper video-container " + className
  }, React__default.createElement("div", {
    dangerouslySetInnerHTML: {
      __html: " " + url_player + " "
    }
  }));
};

SwiperCore.use([Navigation, Pagination, Scrollbar, A11y]);
var ScrollHorizontal = function ScrollHorizontal(_ref) {
  var component = _ref.component,
      data = _ref.data,
      scale = _ref.scale;
  var scale_number = scale ? scale : 0;
  return React__default.createElement("div", {
    className: "scroll-horizontal-wrapper"
  }, React__default.createElement(Swiper, {
    spaceBetween: 10,
    slidesPerView: parseFloat(scale_number + ".5"),
    navigation: true,
    onSlideChange: function onSlideChange() {
      return console.log('slide change');
    },
    onSwiper: function onSwiper(swiper) {
      return console.log(swiper);
    }
  }, data.map(function (item, index) {
    return React__default.createElement(SwiperSlide, {
      key: index
    }, React__default.createElement("div", {
      key: item.id
    }, React__default.cloneElement(component, {
      data: item
    })));
  })));
};

var Modal = function Modal(_ref) {
  var component = _ref.component,
      close = _ref.close,
      className = _ref.className;
  if (!component) return null;
  return React__default.createElement("div", {
    className: "modal-wrapper " + className
  }, React__default.createElement("div", {
    className: "modal-box"
  }, React__default.createElement("div", {
    className: "header"
  }, React__default.createElement("button", {
    className: "btn-transparent",
    onClick: function onClick() {
      return close();
    }
  }, React__default.createElement(IconClose$2, null))), React__default.createElement("div", {
    className: "content"
  }, component)));
};

var TagCategory = function TagCategory(_ref) {
  var children = _ref.children,
      className = _ref.className;
  return React__default.createElement("div", {
    className: "tag-category " + className
  }, children);
};

var TicketList = function TicketList(_ref) {
  var children = _ref.children,
      className = _ref.className;
  var styleClassName = className ? className : '';
  return React__default.createElement("div", {
    className: "ticket-list " + styleClassName
  }, children);
};
var TicketRow = function TicketRow(_ref2) {
  var children = _ref2.children,
      className = _ref2.className;
  var styleClassName = className ? className : '';
  return React__default.createElement("div", {
    className: "ticket-row " + styleClassName
  }, children);
};
var TicketCol = function TicketCol(_ref3) {
  var children = _ref3.children,
      className = _ref3.className;
  var styleClassName = className ? className : '';
  return React__default.createElement("div", {
    className: "ticket-col " + styleClassName
  }, children);
};

var Loading = function Loading(_ref) {
  var visible = _ref.visible,
      className = _ref.className;
  var styleClassName = className ? className : '';

  if (visible) {
    return React__default.createElement("div", {
      className: "loading-animated " + styleClassName
    });
  }

  return null;
};

export { Button, ButtonIcon, Col, Container, Footer, H1, H2, H3, H4, H5, H6, Header, Icons as Icon, Input, JS, LineDivisor, Loading, Modal, Notification, P, Player, Row, ScrollHorizontal, Section, Table, TagCategory, Tbody, Td, Th, Thead, TicketCol, TicketList, TicketRow, Tr };
//# sourceMappingURL=index.modern.js.map
